from sqlalchemy import (
    Column,
    Integer,
    String,
    DateTime,
    func,
    Float
)
from app import db
from sqlalchemy.ext.declarative import DeclarativeMeta

baseModel: DeclarativeMeta = db.Model

class SensorData(baseModel):
    __tablename__ = "sensor_data"
    id = Column(Integer, primary_key=True)
    ga_mac = Column(String, nullable=True)
    dt_mac = Column(String, nullable=True)
    rssi_value = Column(Integer, nullable=True)
    measured_power = Column(Integer, nullable=True)
    distance = Column(Float, nullable=True)
    temp_distance= Column(Float, nullable=True)
    created_at = Column(DateTime(timezone=True), default=func.now())
    updated_at = Column(DateTime(timezone=True), default=func.now())
    cur_time = Column(String, nullable=True)

    @classmethod
    def insert(cls, ga_mac, dt_mac, rssi_value, measured_power):
        """
         Insert a new record to the database
        """
        record = cls(
            ga_mac=ga_mac,
            dt_mac=dt_mac,
            rssi_value=rssi_value,
            measured_power=measured_power
        )
        db.session.add(record)
        db.session.commit()
        return record


class Rawdata(baseModel):
    __tablename__ = "raw_data"
    id = Column(Integer, primary_key=True)
    ga_mac = Column(String, nullable=True)
    dt_mac = Column(String, nullable=True)
    rssi_value = Column(String, nullable=True)
    created_at = Column(DateTime(timezone=True), default=func.now())
    updated_at = Column(DateTime(timezone=True), default=func.now())

    @classmethod
    def insert(cls, ga_mac, dt_mac, rssi_value):
        results = cls(
            ga_mac=ga_mac,
            dt_mac=dt_mac,
            rssi_value=rssi_value,
        )
        db.session.add(results)
        db.session.commit()
        return results

class Mapdata(baseModel):
    __tablename__ = "map_data"
    id = Column(Integer, primary_key=True)
    dt_mac = Column(String, nullable=True)
    x_coordinate = Column(String, nullable=True)
    y_coordinate = Column(String, nullable=True)
    created_at = Column(DateTime(timezone=True), default=func.now())
    updated_at = Column(DateTime(timezone=True), default=func.now())

    @classmethod
    def insert(cls, dt_mac, x_coordinate, y_coordinate):
        results = cls(
            dt_mac=dt_mac,
            x_coordinate=x_coordinate,
            y_coordinate=y_coordinate,
        )
        db.session.add(results)
        db.session.commit()
        return results

class Settings(baseModel):
    __tablename__ = "settings"
    id = Column(Integer, primary_key=True)
    N = Column(Integer, nullable=True)
    c = Column(Integer, nullable=True)
    u = Column(Integer, nullable=True)
    v = Column(Integer, nullable=True)
    created_at = Column(DateTime(timezone=True), default=func.now())
    updated_at = Column(DateTime(timezone=True), default=func.now())

    @classmethod
    def insert(cls, N, c):
        results = cls(
            N=N,
            c=c
        )
        db.session.add(results)
        db.session.commit()
        return results